=========
Reference
=========

.. automodule:: envi
    :members: get, mk_shortcut, get_bool
    :undoc-members:
    :show-inheritance:

.. autofunction:: get_str

.. autofunction:: get_int

.. autofunction:: get_float

.. autoclass:: envi.manager.EnviType
    :members: __init__, integer, bool, float, generic, string

.. autoclass:: envi.manager.EnviManager
    :members: configure
